==> openflowplugin-extension-nicira-0.9.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/ofpact/actions/ofpact/actions/NxActionCtMarkCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions.nx.action.ct.mark._case.NxActionCtMark;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionCtMarkCaseBuilder} instances.
 *
 * @see NxActionCtMarkCaseBuilder
 *
 */
public class NxActionCtMarkCaseBuilder implements Builder<NxActionCtMarkCase> {

    private NxActionCtMark _nxActionCtMark;


    Map<Class<? extends Augmentation<NxActionCtMarkCase>>, Augmentation<NxActionCtMarkCase>> augmentation = Collections.emptyMap();

    public NxActionCtMarkCaseBuilder() {
    }

    public NxActionCtMarkCaseBuilder(NxActionCtMarkCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionCtMarkCase>>, Augmentation<NxActionCtMarkCase>> aug =((AugmentationHolder<NxActionCtMarkCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxActionCtMark = base.getNxActionCtMark();
    }


    public NxActionCtMark getNxActionCtMark() {
        return _nxActionCtMark;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionCtMarkCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionCtMarkCaseBuilder setNxActionCtMark(final NxActionCtMark value) {
        this._nxActionCtMark = value;
        return this;
    }
    
    public NxActionCtMarkCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionCtMarkCase>> augmentationType, Augmentation<NxActionCtMarkCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionCtMarkCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionCtMarkCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionCtMarkCase build() {
        return new NxActionCtMarkCaseImpl(this);
    }

    private static final class NxActionCtMarkCaseImpl
        extends AbstractAugmentable<NxActionCtMarkCase>
        implements NxActionCtMarkCase {
    
        private final NxActionCtMark _nxActionCtMark;
    
        NxActionCtMarkCaseImpl(NxActionCtMarkCaseBuilder base) {
            super(base.augmentation);
            this._nxActionCtMark = base.getNxActionCtMark();
        }
    
        @Override
        public NxActionCtMark getNxActionCtMark() {
            return _nxActionCtMark;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxActionCtMark);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionCtMarkCase.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            NxActionCtMarkCase other = (NxActionCtMarkCase)obj;
            if (!Objects.equals(_nxActionCtMark, other.getNxActionCtMark())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionCtMarkCaseImpl otherImpl = (NxActionCtMarkCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionCtMarkCase>>, Augmentation<NxActionCtMarkCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionCtMarkCase");
            CodeHelpers.appendValue(helper, "_nxActionCtMark", _nxActionCtMark);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.10.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/ofpact/actions/ofpact/actions/NxActionCtMarkCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.ofpact.actions.nx.action.ct.mark._case.NxActionCtMark;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionCtMarkCaseBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxActionCtMarkCaseBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxActionCtMarkCaseBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxActionCtMarkCaseBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxActionCtMarkCaseBuilder
 * @see Builder
 *
 */
public class NxActionCtMarkCaseBuilder implements Builder<NxActionCtMarkCase> {

    private NxActionCtMark _nxActionCtMark;


    Map<Class<? extends Augmentation<NxActionCtMarkCase>>, Augmentation<NxActionCtMarkCase>> augmentation = Collections.emptyMap();

    public NxActionCtMarkCaseBuilder() {
    }

    public NxActionCtMarkCaseBuilder(NxActionCtMarkCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionCtMarkCase>>, Augmentation<NxActionCtMarkCase>> aug =((AugmentationHolder<NxActionCtMarkCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxActionCtMark = base.getNxActionCtMark();
    }


    public NxActionCtMark getNxActionCtMark() {
        return _nxActionCtMark;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionCtMarkCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionCtMarkCaseBuilder setNxActionCtMark(final NxActionCtMark value) {
        this._nxActionCtMark = value;
        return this;
    }
    
    public NxActionCtMarkCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionCtMarkCase>> augmentationType, Augmentation<NxActionCtMarkCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionCtMarkCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionCtMarkCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionCtMarkCase build() {
        return new NxActionCtMarkCaseImpl(this);
    }

    private static final class NxActionCtMarkCaseImpl
        extends AbstractAugmentable<NxActionCtMarkCase>
        implements NxActionCtMarkCase {
    
        private final NxActionCtMark _nxActionCtMark;
    
        NxActionCtMarkCaseImpl(NxActionCtMarkCaseBuilder base) {
            super(base.augmentation);
            this._nxActionCtMark = base.getNxActionCtMark();
        }
    
        @Override
        public NxActionCtMark getNxActionCtMark() {
            return _nxActionCtMark;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxActionCtMark);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionCtMarkCase.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            NxActionCtMarkCase other = (NxActionCtMarkCase)obj;
            if (!Objects.equals(_nxActionCtMark, other.getNxActionCtMark())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionCtMarkCaseImpl otherImpl = (NxActionCtMarkCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionCtMarkCase>>, Augmentation<NxActionCtMarkCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionCtMarkCase");
            CodeHelpers.appendValue(helper, "_nxActionCtMark", _nxActionCtMark);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
